Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Verified Permissions.

Actions, resources, and condition keys for Amazon Verified Permissions - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Verified Permissions

Amazon Verified Permissions (service prefix: `verifiedpermissions` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon Verified Permissions
- Resource types defined by Amazon Verified Permissions
- Condition keys for Amazon Verified Permissions

## Actions defined by Amazon Verified Permissions

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateIdentitySource | Grants permission to create a reference to an external identity provider (IdP) that is compatible with OpenID Connect (OIDC) authentication protocol, such as Amazon Cognito | Write | policy-store* |  |
CreatePolicy | Grants permission to create a Cedar policy and save it in the specified policy store | Write | policy-store* |  |
CreatePolicyStore | Grants permission to create a Cedar policy and save it in the specified policy store | Write |  |  |
CreatePolicyTemplate | Grants permission to create a policy template | Write | policy-store* |  |
DeleteIdentitySource | Grants permission to delete an identity source that references an identity provider (IdP) such as Amazon Cognito | Write | policy-store* |  |
DeletePolicy | Grants permission to delete the specified policy from the policy store | Write | policy-store* |  |
DeletePolicyStore | Grants permission to delete the specified policy store | Write | policy-store* |  |
DeletePolicyTemplate | Grants permission to delete the specified policy template from the policy store | Write | policy-store* |  |
GetIdentitySource | Grants permission to retrieve the details about the specified identity source | Read | policy-store* |  |
GetPolicy | Grants permission to retrieve information about the specified policy | Read | policy-store* |  |
GetPolicyStore | Grants permission to retrieve details about a policy store | Read | policy-store* |  |
GetPolicyTemplate | Grants permission to retrieve the details for the specified policy template in the specified policy store | Read | policy-store* |  |
GetSchema | Grants permission to retrieve the details for the specified schema in the specified policy store | Read | policy-store* |  |
IsAuthorized | Grants permission to make an authorization decision about a service request described in the parameters | Read | policy-store* |  |
IsAuthorizedWithToken | Grants permission to make an authorization decision about a service request described in the parameters. The principal in this request comes from an external identity source | Read | policy-store* |  |
ListIdentitySources | Grants permission to return a paginated list of all of the identity sources defined in the specified policy store | List | policy-store* |  |
ListPolicies | Grants permission to return a paginated list of all policies stored in the specified policy store | List | policy-store* |  |
ListPolicyStores | Grants permission to return a paginated list of all policy stores in the calling Amazon Web Services account | List |  |  |
ListPolicyTemplates | Grants permission to return a paginated list of all policy templates in the specified policy store | List | policy-store* |  |
PutSchema | Grants permission to create or update the policy schema in the specified policy store | Write | policy-store* |  |
UpdateIdentitySource | Grants permission to update the specified identity source to use a new identity provider (IdP) source, or to change the mapping of identities from the IdP to a different principal entity type | Write | policy-store* |  |
UpdatePolicy | Grants permission to modify the specified Cedar static policy in the specified policy store | Write | policy-store* |  |
UpdatePolicyStore | Grants permission to modify the validation setting for a policy store | Write | policy-store* |  |
UpdatePolicyTemplate | Grants permission to update the specified policy template | Write | policy-store* |  |

## Resource types defined by Amazon Verified Permissions

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
policy-store | `arn:$ { Partition}:verifiedpermissions::$ { Account}:policy-store/$ { PolicyStoreId}` |

## Condition keys for Amazon Verified Permissions

Verified Permissions has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.